Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAllTradeGoods ¶
func GetAllTradeGoods(resources []climategen.Resource) []string
GetAllTradeGoods converts a list of resources into a list of trade goods
Types ¶
type NamePattern ¶
NamePattern is a type of naming style for town names
type Town ¶
type Town struct {
Name string
Population int
Category TownCategory
Climate climategen.Climate
Culture culturegen.Culture
Mayor chargen.Character
Exports []TradeGood
Imports []TradeGood
}
Town is a town
func GenerateTown ¶
GenerateTown generates a random town
func SetCulture ¶
func SetCulture(culture culturegen.Culture, town Town) Town
SetCulture sets the culture of a town and recalculates some things
Click to show internal directories.
Click to hide internal directories.